@@ -1,6 +1,6 @@
 `text2spc.fnc` <-
 function(text) {
-  if (!require("zipfR", quietly = TRUE, character = TRUE)) {
+  if (!require("zipfR", quietly = TRUE)) {
     stop("please install the zipfR library first")
   } else {
     tab = table(table(text))
